@@ -1,7 +1,5 @@
 #include "../h/gsupport.h"
 
-#undef COMPILER
-#define COMPILER 1        /* insure compiler Version number */
 #include "../h/version.h"
 
 extern char *progname;
@@ -10,8 +8,7 @@ extern char *progname;
  * id_comment - output a comment C identifying the date and time and what
  *  program is producing the output.
  */
-void id_comment(f)
-FILE *f;
+void id_comment(FILE *f)
    {
    static char sbuf[26];
    static int first_time = 1;
