@@ -15,10 +15,10 @@
  *	$error [text]
  *
  *  Entry points are
- *	ppinit(fname,inclpath,m4flag) -- open input file
+ *	ppinit(fname,inclpath) -- open input file
  *	ppdef(s,v) -- "$define s v", or "$undef s" if v is a null pointer
  *	ppch() -- return next preprocessed character
- *	ppecho() -- preprocess to stdout (for icont/iconc -E)
+ *	ppecho() -- preprocess to stdout (for icont -E)
  *
  *  See ../h/features.h for the set of predefined symbols.
  */
@@ -32,7 +32,6 @@ typedef struct fstruct {		/* input file structure */
    char *fname;				/* file name */
    long lno;				/* line number */
    FILE *fp;				/* stdio file pointer */
-   int m4flag;				/* nz if preprocessed by m4 */
    int ifdepth;				/* $if nesting depth when opened */
    } infile;
 
@@ -57,8 +56,7 @@ typedef struct cd {			/* structure holding a definition */
    char s[1];				/* name then value, as needed, no \0 */
    } cdefn;
 
-static	int	ppopen	(char *fname, int m4);
-static	FILE *	m4pipe	(char *fname);
+static	int	ppopen	(char *fname);
 static	char *	rline	(FILE *fp);
 static	void	pushdef	(cdefn *d);
 static	void	pushline (char *fname, long lno);
@@ -84,7 +82,7 @@ static	cdefn *	dlookup	(char *name, int len, char *val);
 
 struct ppcmd {
    char *name;
-   char *(*func)();
+   char *(*func)(char *);
    }
 pplist[] = {
    { "define",  define  },
@@ -115,17 +113,14 @@ static char *lpath;			/* LPATH for finding source files */
 
 static int ifdepth;			/* depth of $if nesting */
 
-extern int tfatals, nocode;		/* provided by icont, iconc */
+extern int tfatals, nocode;		/* provided by icont */
 
 /*
- * ppinit(fname, inclpath, m4) -- initialize preprocessor to read from fname.
+ * ppinit(fname, inclpath) -- initialize preprocessor to read from fname.
  *
  *  Returns 1 if successful, 0 if open failed.
  */
-int ppinit(fname, inclpath, m4)
-char *fname;
-char *inclpath;
-int m4;
+int ppinit(char *fname, char *inclpath)
    {
    int i;
    cdefn *d, *n;
@@ -152,19 +147,17 @@ int m4;
     */
    lpath = inclpath;
    curfile = &nofile;			/* init file struct pointer */
-   return ppopen(fname, m4);		/* open main source file */
+   return ppopen(fname);		/* open main source file */
    }
 
 /*
- * ppopen(fname, m4) -- open a new file for reading by the preprocessor.
+ * ppopen(fname) -- open a new file for reading by the preprocessor.
  *
  *  Returns 1 if successful, 0 if open failed.
  *
  *  Open calls may be nested.  Files are closed when EOF is read.
  */
-static int ppopen(fname, m4)
-char *fname;
-int m4;
+static int ppopen(char *fname)
    {
    FILE *f;
    infile *fs;
@@ -174,9 +167,7 @@ int m4;
          pfatal("circular include", fname);	/* issue error message */
          return 1;				/* treat as success */
          }
-   if (m4)
-      f = m4pipe(fname);
-   else if (curfile == &nofile && strcmp(fname, "-") == 0) { /* 1st file only */
+   if (curfile == &nofile && strcmp(fname, "-") == 0) { /* 1st file only */
       f = stdin;
       fname = "stdin";
       }
@@ -190,27 +181,12 @@ int m4;
    fs->fp = f;
    fs->fname = salloc(fname);
    fs->lno = 0;
-   fs->m4flag = m4;
    fs->ifdepth = ifdepth;
    pushline(fs->fname, 0L);
    curfile = fs;
    return 1;
    }
 
-/*
- * m4pipe -- open a pipe from m4.
- */
-static FILE *m4pipe(filename)
-char *filename;
-   {
-   FILE *f;
-   char *s = alloc(4 + strlen(filename));
-   sprintf(s, "m4 %s", filename);
-   f = popen(s, "r");
-   free(s);
-   return f;
-   }
-
 /*
  * ppdef(s,v) -- define/undefine a symbol
  *
@@ -218,8 +194,7 @@ char *filename;
  *  Otherwise, defines s to have the value v.
  *  No error is given for a redefinition.
  */
-void ppdef(s, v)
-char *s, *v;
+void ppdef(char *s, char *v)
    {
    dlookup(s, -1, (char *)NULL);
    if (v != NULL)
@@ -369,15 +344,7 @@ int ppch()
           */
          fs = curfile;
          curfile = fs->prev;
-
-         if (fs->m4flag) {			/* if m4 preprocessing */
-            void quit();
-            if (pclose(fs->fp) != 0)		/* close pipe */
-               quit("m4 terminated abnormally");
-            }
-         else
-            fclose(fs->fp);		/* close current file */
-
+         fclose(fs->fp);		/* close current file */
          free((char *)fs->fname);
          free((char *)fs);
          if (curfile == &nofile)	/* if at outer level, return EOF */
@@ -393,8 +360,7 @@ int ppch()
  *
  *  Allocates memory as needed.  Returns NULL for EOF.  Lines end with "\n\0".
  */
-static char *rline(fp)
-FILE *fp;
+static char *rline(FILE *fp)
    {
 #define LINE_SIZE_INIT 100
 #define LINE_SIZE_INCR 100
@@ -445,8 +411,7 @@ FILE *fp;
 /*
  * pushdef(d) -- insert definition into the input stream.
  */
-static void pushdef(d)
-cdefn *d;
+static void pushdef(cdefn *d)
    {
    buffer *b;
 
@@ -469,9 +434,7 @@ cdefn *d;
 /*
  * pushline(fname,lno) -- push #line directive into input stream.
  */
-static void pushline(fname, lno)
-char *fname;
-long lno;
+static void pushline(char *fname, long lno)
    {
    static char tbuf[200];
 
@@ -485,8 +448,7 @@ long lno;
  *
  *  s is the portion of the line following the $.
  */
-static void ppdir(s)
-char *s;
+static void ppdir(char *s)
    {
    char b0, *cmd, *errmsg;
    struct ppcmd *p;
@@ -519,8 +481,7 @@ char *s;
  *  We can't use tfatal() because we have our own line counter which may be
  *  out of sync with the lexical analyzer's.
  */
-static void pfatal(s1, s2)
-char *s1, *s2;
+static void pfatal(char *s1, char *s2)
    {
    int n;
 
@@ -539,8 +500,7 @@ char *s1, *s2;
 /*
  * errdir(s) -- handle deliberate $error.
  */
-static char *errdir(s)
-char *s;
+static char *errdir(char *s)
    {
    pfatal("explicit $error", s);		/* issue msg with text */
    return NULL;
@@ -549,8 +509,7 @@ char *s;
 /*
  * define(s) -- handle $define directive.
  */
-static char *define(s)
-char *s;
+static char *define(char *s)
    {
    char c, *name, *val;
 
@@ -581,8 +540,7 @@ char *s;
 /*
  * undef(s) -- handle $undef directive.
  */
-static char *undef(s)
-char *s;
+static char *undef(char *s)
    {
    char c, *name;
 
@@ -599,8 +557,7 @@ char *s;
 /*
  * include(s) -- handle $include directive.
  */
-static char *include(s)
-char *s;
+static char *include(char *s)
    {
    char *fname;
    char fullpath[MaxPath];
@@ -610,7 +567,7 @@ char *s;
       return "$include: invalid file name";
    if (*wskip(s) != '\0')
       return "$include: too many arguments";
-   if (!pathfind(fullpath, lpath, fname, (char *)NULL) || !ppopen(fullpath, 0))
+   if (!pathfind(fullpath, lpath, fname, (char *)NULL) || !ppopen(fullpath))
       pfatal("cannot open", fname);
    return NULL;
    }
@@ -618,8 +575,7 @@ char *s;
 /*
  * setline(s) -- handle $line (or #line) directive.
  */
-static char *setline(s)
-char *s;
+static char *setline(char *s)
    {
    long n;
    char c;
@@ -657,14 +613,12 @@ char *s;
 /*
  * ifdef(s), ifndef(s) -- conditional processing if s is/isn't defined.
  */
-static char *ifdef(s)
-char *s;
+static char *ifdef(char *s)
    {
    return ifxdef(s, 1);
    }
 
-static char *ifndef(s)
-char *s;
+static char *ifndef(char *s)
    {
    return ifxdef(s, 0);
    }
@@ -672,9 +626,7 @@ char *s;
 /*
  * ifxdef(s) -- handle $ifdef (if n is 1) or $ifndef (if n is 0).
  */
-static char *ifxdef(s, f)
-char *s;
-int f;
+static char *ifxdef(char *s, int f)
    {
    char c, *name;
 
@@ -693,8 +645,7 @@ int f;
 /*
  * elsedir(s) -- handle $else by skipping to $endif.
  */
-static char *elsedir(s)
-char *s;
+static char *elsedir(char *s)
    {
    if (ifdepth <= curfile->ifdepth)
       return "unexpected $else";
@@ -707,8 +658,7 @@ char *s;
 /*
  * endif(s) -- handle $endif.
  */
-static char *endif(s)
-char *s;
+static char *endif(char *s)
    {
    if (ifdepth <= curfile->ifdepth)
       return "unexpected $endif";
@@ -723,8 +673,7 @@ char *s;
  *
  *  If report is nonzero, generate #line directive at end of skip.
  */
-static void skipcode(doelse, report)
-int doelse, report;
+static void skipcode(int doelse, int report)
    {
    char c, *p, *cmd;
 
@@ -792,8 +741,7 @@ int doelse, report;
  *
  *  If '#' is encountered, skips to end of string.
  */
-static char *wskip(s)
-char *s;
+static char *wskip(char *s)
    {
    char c;
 
@@ -808,8 +756,7 @@ char *s;
 /*
  * nskip(s) -- skip over numeric constant and return updated pointer.
  */
-static char *nskip(s)
-char *s;
+static char *nskip(char *s)
    {
       char c;
 
@@ -841,8 +788,7 @@ char *s;
  *  the string.  Escaped quote characters do not stop the scan.  The
  *  updated pointer is returned.
  */
-static char *matchq(s)
-char *s;
+static char *matchq(char *s)
    {
    char c, q;
 
@@ -868,8 +814,7 @@ char *s;
  *  is typically done to avoid the need for another arbitrarily-long
  *  buffer.  An offset of -1 allows room for insertion of the '\0'.
  */
-static char *getidt(dst, src)
-char *dst, *src;
+static char *getidt(char *dst, char *src)
    {
    char c;
 
@@ -887,8 +832,7 @@ char *dst, *src;
  *  Similarly to getidt, getfnm extracts a quoted or unquoted file name.
  *  An empty string at dst indicates a missing or unterminated file name.
  */
-static char *getfnm(dst, src)
-char *dst, *src;
+static char *getfnm(char *dst, char *src)
    {
    char *lim;
 
@@ -916,10 +860,7 @@ char *dst, *src;
  *  If name is null, the call is ignored.
  *  If len < 0, strlen(name) is taken.
  */
-static cdefn *dlookup(name, len, val)
-char *name;
-int len;
-char *val;
+static cdefn *dlookup(char *name, int len, char *val)
    {
    int h, i, nlen, vlen;
    unsigned int t;
