@@ -8,10 +8,7 @@
  * Write a long string in int-sized chunks.
  */
 
-long longwrite(s,len,file)
-FILE *file;
-char *s;
-long len;
+long longwrite(char *s, long len, FILE *file)
 {
    long tally = 0;
    int n = 0;
