@@ -2,6 +2,11 @@
  * Interpreter code file header - this is written at the start of
  *  an icode file after the start-up program.
  */
+
+#define IHEADER_MAGIC 0x96C53A69	/* confirms validity of flags word */
+
+#define IHEADER_PROFILING 0x00000001	/* set if profiling */
+
 struct header {
    word hsize;			/* size of interpreter code */
    word trace;			/* initial value of &trace */
@@ -15,16 +20,14 @@ struct header {
    word Strcons;		/* location of identifier table */
    word Filenms;		/* location of ipc/file name table */
 
-#ifdef FieldTableCompression
-   short FtabWidth;		/* width of field table entries, 1 | 2 | 4 */
-   short FoffWidth;		/* width of field offset entries, 1 | 2 | 4 */
-   word Nfields;		/* number of field names */
-   word Fo;			/* The start of the Fo array */
-   word Bm;			/* The start of the Bm array */
-#endif					/* FieldTableCompression */
-
    word linenums;		/* location of ipc/line number table */
-   word config[16];		/* icode version */
-
+   word iversion[4];		/* icode version */
 
+   /*
+    * Through Icon 9.5.0, the following were written from uninitialized memory;
+    * they should be treated as valid only if "magic" is correct.
+    */
+   word magic;			/* should equal IHEADER_MAGIC */
+   word flags;			/* flag bits defined above */
+   word future[10];		/* padding for compatibility and future use */
    };
