@@ -21,7 +21,7 @@ struct b_selem	*alcselem	(dptr mbr,uword hn);
 char		*alcstr		(char	*s,word slen);
 struct b_telem	*alctelem	(void);
 struct b_tvtbl	*alctvtbl	(dptr tbl,dptr ref,uword hashnum);
-int		anycmp		(dptr dp1,dptr dp2);
+int		anycmp		(const void *dp1,const void *dp2);
 int		bfunc		(void);
 struct b_proc	*bi_strprc	(dptr s, C_integer arity);
 void		c_exit		(int i);
@@ -70,7 +70,6 @@ int		def_tstr	(char *sbuf, dptr s, dptr df, dptr d);
 word		div3		(word a,word b);
 int		doasgn		(dptr dp1,dptr dp2);
 int		doimage		(int c,int q);
-int		dp_pnmcmp	(struct pstrnm *pne,dptr dp);
 void		drunerr		(int n, double v);
 void		dumpact		(struct b_coexpr *ce);
 void		env_int	(char *name,word *variable,int non_neg, uword limit);
@@ -109,11 +108,9 @@ int		numcmp		(dptr dp1,dptr dp2,dptr dp3);
 void		outimage	(FILE *f,dptr dp,int noimage);
 struct b_coexpr	*popact		(struct b_coexpr *ce);
 word		prescan		(dptr d);
-int		pstrnmcmp	(struct pstrnm *a,struct pstrnm *b);
+int		pstrnmcmp	(const void *ps1, const void *ps2);
 int		pushact		(struct b_coexpr *ce, struct b_coexpr *actvtr);
 int		putstr		(FILE *f,dptr d);
-char		*qsearch	(char *key, char *base, int nel, int width,
-				   int (*cmp)());
 int		qtos		(dptr dp,char *sbuf);
 void		quittrap	(int);
 int		 radix		(int sign, register int r, register char *s,
@@ -171,7 +168,7 @@ int		bigrand		(dptr da, dptr dx);
    int	docircles	(wbp w, int argc, dptr argv, int fill);
    void	drawCurve	(wbp w, XPoint *p, int n);
    char	*evquesub	(wbp w, int i);
-   void	genCurve	(wbp w, XPoint *p, int n, void (*h)());
+   void	genCurve	(wbp w, XPoint *p, int n, void (*h)(wbp,XPoint[],int));
    wsp	getactivewindow	(void);
    int	getpattern	(wbp w, char *answer);
    struct palentry *palsetup(int p);
@@ -188,7 +185,6 @@ int		bigrand		(dptr da, dptr dx);
    int	setsize		(wbp w, char *s);
    char	*si_i2s		(siptr sip, int i);
    int	si_s2i		(siptr sip, char *s);
-   int	ulcmp		(pointer p1, pointer p2);
    int	wattrib		(wbp w, char *s, long len, dptr answer, char *abuf);
    int	wgetche		(wbp w, dptr res);
    int	wgetchne	(wbp w, dptr res);
@@ -407,7 +403,7 @@ C_integer iipow		(C_integer n1, C_integer n2);
 void	init		(char *name, int *argcp, char *argv[], int trc_init);
 int	kbhit		(void);
 int	mkreal		(double r,dptr dp);
-int	nthcmp		(dptr d1,dptr d2);
+int	nthcmp		(const void *d1,const void *d2);
 void	nxttab		(C_integer *col, dptr *tablst, dptr endlst,
 			   C_integer *last, C_integer *interval);
 int	order		(dptr dp);
@@ -417,10 +413,10 @@ void	rtos		(double n,dptr dp,char *s);
 int	sig_rsm		(void);
 struct b_proc *strprc	(dptr s, C_integer arity);
 int	subs_asgn	(dptr dest, const dptr src);
-int	trcmp3		(struct dpair *dp1,struct dpair *dp2);
-int	trefcmp		(dptr d1,dptr d2);
-int	tvalcmp		(dptr d1,dptr d2);
-int	tvcmp4		(struct dpair *dp1,struct dpair *dp2);
+int	trcmp3		(const void *dp1, const void *dp2);
+int	trefcmp		(const void *d1, const void *d2);
+int	tvalcmp		(const void *d1, const void *d2);
+int	tvcmp4		(const void *dp1, const void *dp2);
 int	tvtbl_asgn	(dptr dest, const dptr src);
 void	varargs		(dptr argp, int nargs, dptr rslt);
 
