@@ -1,6 +1,11 @@
 #ifndef RT_DOT_H	/* only include once */
 #define RT_DOT_H 1
 
+/*
+ * Inhibit complaints about unnecessary generated parentheses.
+ */
+#pragma clang diagnostic ignored "-Wparentheses"
+
 /*
  * Include files.
  */
@@ -13,7 +18,6 @@
 #include "../h/cstructs.h"
 #include "../h/mproto.h"
 #include "../h/cpuconf.h"
-#include "../h/monitor.h"
 #include "../h/rmacros.h"
 #include "../h/rstructs.h"
 
