@@ -25,11 +25,10 @@ void readglob()
    {
    register word id;
    register int n, op;
-   int k;
+   int i, k;
    int implicit;
    char *name;
    struct gentry *gp;
-   extern char *progname;
 
    if (getopc(&name) != Op_Version)
       quitf("ucode file %s has no version identification",inname);
@@ -111,7 +110,8 @@ void readglob()
             break;
 
          case Op_Link:		/* link the named file */
-            name = &lsspace[getrest()];	/* get the name and */
+            i = getrest();  /* get name offset -- can move lsspace */
+            name = &lsspace[i];	/* get pointer to name string */
             alsolink(name);	/*  put it on the list of files to link */
             newline();
             break;
@@ -281,8 +281,7 @@ void scanrefs()
 /*
  * scanfile -- scan one file for references.
  */
-static void scanfile(filename)
-char *filename;
+static void scanfile(char *filename)
    {
    int i, k, f, op, nrefs, flags;
    word id, procid;
@@ -342,8 +341,7 @@ char *filename;
 /*
  *
  */
-static void reference(gp)
-struct gentry *gp;
+static void reference(struct gentry *gp)
    {
    struct gentry **rp;
 
