@@ -19,11 +19,6 @@ static	void	setexe	(char *fname);
 FILE *infile;				/* input file (.u1 or .u2) */
 FILE *outfile;				/* interpreter code output file */
 
-#ifdef DeBugLinker
-   FILE *dbgfile;			/* debug file */
-   static char dbgname[MaxPath];	/* debug file name */
-#endif					/* DeBugLinker */
-
 struct lfile *llfiles = NULL;		/* List of files to link */
 
 char inname[MaxPath];			/* input file name */
@@ -36,9 +31,7 @@ int fatals = 0;				/* number of errors encountered */
 /*
  *  ilink - link a number of files, returning error count
  */
-int ilink(ifiles,outname)
-char **ifiles;
-char *outname;
+int ilink(char **ifiles, char *outname)
    {
    int i;
    struct lfile *lf,*lfls;
@@ -127,7 +120,7 @@ char *outname;
          "[ -x \"$IXBIN\" ] && exec \"$IXBIN\" $0 ${1+\"$@\"}",
          "exec iconx $0 ${1+\"$@\"}",
          "[executable Icon binary follows]");
-      strcat(script, "        \n\f\n" + ((int)(strlen(script) + 4) % 8));
+      strcat(script, &"        \n\f\n"[(int)(strlen(script) + 4) % 8]);
       hdrsize = strlen(script) + 1;	/* length includes \0 at end */
       fwrite(script, hdrsize, 1, outfile);	/* write header */
       }
@@ -140,18 +133,6 @@ char *outname;
    if (ferror(outfile) != 0)
       quit("unable to write to icode file");
 
-   #ifdef DeBugLinker
-      /*
-       * Open the .ux file if debugging is on.
-       */
-      if (Dflag) {
-         makename(dbgname, TargetDir, llfiles->lf_name, ".ux");
-         dbgfile = fopen(dbgname, "w");
-         if (dbgfile == NULL)
-            quitf("cannot create %s", dbgname);
-         }
-   #endif				/* DeBugLinker */
-
    /*
     * Loop through input files and generate code for each.
     */
@@ -181,8 +162,7 @@ char *outname;
 /*
  * lwarn - issue a linker warning message.
  */
-void lwarn(s1, s2, s3)
-char *s1, *s2, *s3;
+void lwarn(char *s1, char *s2, char *s3)
    {
    fprintf(stderr, "%s: ", icnname);
    if (lineno)
@@ -195,8 +175,7 @@ char *s1, *s2, *s3;
  * lfatal - issue a fatal linker error message.
  */
 
-void lfatal(s1, s2)
-char *s1, *s2;
+void lfatal(char *s1, char *s2)
    {
    fatals++;
    fprintf(stderr, "%s: ", icnname);
@@ -209,8 +188,7 @@ char *s1, *s2;
  * setexe - mark the output file as executable
  */
 
-static void setexe(fname)
-char *fname;
+static void setexe(char *fname)
    {
    struct stat stbuf;
    int u, r, m;
