@@ -41,6 +41,7 @@ int main(int argc, char *argv[]) {
    char **rptr;				/* list of files to remove */
    char *efile = NULL;			/* stderr file */
    char buf[MaxPath];			/* file name construction buffer */
+   char *ppath;				/* ICONPROFILE value */
    int c, n;
    char ch;
    struct fileparts *fp;
@@ -55,13 +56,16 @@ int main(int argc, char *argv[]) {
       iconxloc = patchpath + 18;	/* use stated iconx path if patched */
    else
       iconxloc = relfile(argv[0], "/../iconx");	/* otherwise infer it */
+   ppath = getenv("ICONPROFILE");
+   if (ppath != NULL && ppath[0] != '\0')
+      profile = 1;			/* ICONPROFILE implies -p */
 
    /*
     * Process options.
     * IMPORTANT:  When making changes here,
     * also update usage() function and man page.
     */
-   while ((c = getopt(argc, argv, "+ce:f:o:stuv:ELNP:VX:")) != EOF)
+   while ((c = getopt(argc, argv, "+ce:f:o:pstuv:ENP:VX:")) != EOF)
       switch (c) {
          case 'c':			/* -c: compile only (no linking) */
             nolink = 1;
@@ -76,6 +80,9 @@ int main(int argc, char *argv[]) {
          case 'o':			/* -o file: name output file */
             ofile = optarg;
             break;
+         case 'p':			/* -p: enable icode profiling */
+            profile = 1;
+            break;
          case 's':			/* -s: suppress informative messages */
             silent = 1;
             verbose = 0;
@@ -103,20 +110,14 @@ int main(int argc, char *argv[]) {
             iconxloc = "";
             break;
          case 'V':			/* -V: print version information */
-            fprintf(stderr, "%s  (%s, %s)\n", Version, Config, __DATE__);
+            fprintf(stderr, "%s  (%s %d/%d, %s)\n",
+               Version, Config, IntBits, WordBits, __DATE__);
             if (optind == argc)
                exit(0);
             break;
          case 'X':			/* -X srcfile: execute single srcfile */
             txrun(copyfile, optarg, &argv[optind]);
             break;	/*NOTREACHED*/
-
-         #ifdef DeBugLinker
-            case 'L':			/* -L: enable linker debugging */
-               Dflag = 1;
-               break;
-         #endif				/* DeBugLinker */
-
          default:
          case 'x':			/* -x illegal until after file list */
             usage();
@@ -249,8 +250,10 @@ static void execute(char *ofile, char *efile, char *args[]) {
     */
    if (efile != NULL) {
       close(fileno(stderr));
-      if (strcmp(efile, "-") == 0)
-         dup(fileno(stdout));
+      if (strcmp(efile, "-") == 0) {
+         if (dup(fileno(stdout)) < 0)
+            quit("could not merge standard output with standard error\n");
+         }
       else if (freopen(efile, "w", stderr) == NULL)
          quitf("could not redirect stderr to %s\n", efile);
       }
@@ -281,7 +284,7 @@ static void usage(void) {
    fprintf(stderr, "usage: icon  sourcefile   [args]\n");
    fprintf(stderr, "       icon  -P 'program' [args]\n");
    fprintf(stderr, "       icont %s\n",
-      "[-cstuENV] [-f s] [-o ofile] [-v i] file ... [-x args]");
+      "[-cpstuENV] [-f s] [-o ofile] [-v i] file ... [-x args]");
    exit(EXIT_FAILURE);
    }
 
@@ -293,11 +296,7 @@ static char *libpath(char *prog, char *envname) {
 
    s = getenv(envname);
    if (s != NULL)
-      #if CYGWIN
-         cygwin_win32_to_posix_path_list(s, buf);
-      #else				/* CYGWIN */
-         strcpy(buf, s);
-      #endif				/* CYGWIN */
+      strcpy(buf, s);
    else
       strcpy(buf, ".");
    strcat(buf, ":");
@@ -323,21 +322,15 @@ static void txrun(char *(*func)(FILE*, char*), char *source, char *args[]) {
    omask = umask(0077);		/* remember umask; keep /tmp files private */
 
    /*
-    * Invent a file named /tmp/innnnnxx.icn.
+    * Create a temporary file named /tmp/innnnnxx.icn.
     */
    srand(time(NULL));
    c1 = abet[rand() % (sizeof(abet) - 1)];
    c2 = abet[rand() % (sizeof(abet) - 1)];
    sprintf(srcfile, "/tmp/i%d%c%c.icn", getpid(), c1, c2);
-
-   /*
-    * Copy the source code to the temporary file.
-    */
    f = fopen(srcfile, "w");
    if (f == NULL)
       quitf("cannot open for writing: %s", srcfile);
-   progname = func(f, source);
-   fclose(f);
 
    /*
     * Derive other names and arrange for cleanup on exit.
@@ -351,8 +344,22 @@ static void txrun(char *(*func)(FILE*, char*), char *source, char *args[]) {
    atexit(cleanup);
 
    /*
-    * Translate to produce .u1 and .u2 files.
+    * If source is from a file, prepend its directory to LPATH.
     */
+   if (func == copyfile) {
+      sprintf(buf, "%s/..", source);
+      canonize(buf);
+      strcat(buf, ":");
+      strcat(buf, lpath);
+      free(lpath);
+      lpath = salloc(buf);
+      }
+
+   /*
+    * Copy the source file, then translate to produce .u1 and .u2 files.
+    */
+   progname = func(f, source);
+   fclose(f);
    flist[0] = srcfile;
    flist[1] = NULL;
    if (trans(flist, SourceDir) > 0)
