@@ -25,9 +25,7 @@ static struct finfo_lst *file_lst = NULL;
 /*
  * errt1 - error message in one string, location indicated by a token.
  */
-void errt1(t, s)
-struct token *t;
-char *s;
+void errt1(struct token *t, char *s)
    {
    errfl1(t->fname, t->line, s);
    }
@@ -35,10 +33,7 @@ char *s;
 /*
  * errfl1 - error message in one string, location given by file and line.
  */
-void errfl1(f, l, s)
-char *f;
-int l;
-char *s;
+void errfl1(char *f, int l, char *s)
    {
    fflush(stdout);
    fprintf(stderr, "%s: File %s; Line %d: %s\n", progname, f, l, s);
@@ -49,8 +44,7 @@ char *s;
 /*
  * err1 - error message in one string, no location given
  */
-void err1(s)
-char *s;
+void err1(char *s)
    {
    fflush(stdout);
    fprintf(stderr, "%s: %s\n", progname, s);
@@ -61,10 +55,7 @@ char *s;
 /*
  * errt2 - error message in two strings, location indicated by a token.
  */
-void errt2(t, s1, s2)
-struct token *t;
-char *s1;
-char *s2;
+void errt2(struct token *t, char *s1, char *s2)
    {
    errfl2(t->fname, t->line, s1, s2);
    }
@@ -72,11 +63,7 @@ char *s2;
 /*
  * errfl2 - error message in two strings, location given by file and line.
  */
-void errfl2(f, l, s1, s2)
-char *f;
-int l;
-char *s1;
-char *s2;
+void errfl2(char *f, int l, char *s1, char *s2)
    {
    fflush(stdout);
    fprintf(stderr, "%s: File %s; Line %d: %s%s\n", progname, f, l, s1, s2);
@@ -87,9 +74,7 @@ char *s2;
 /*
  * err2 - error message in two strings, no location given
  */
-void err2(s1, s2)
-char *s1;
-char *s2;
+void err2(char *s1, char *s2)
    {
    fflush(stdout);
    fprintf(stderr, "%s: %s%s\n", progname, s1, s2);
@@ -100,11 +85,7 @@ char *s2;
 /*
  * errt3 - error message in three strings, location indicated by a token.
  */
-void errt3(t, s1, s2, s3)
-struct token *t;
-char *s1;
-char *s2;
-char *s3;
+void errt3(struct token *t, char *s1, char *s2, char *s3)
    {
    errfl3(t->fname, t->line, s1, s2, s3);
    }
@@ -112,12 +93,7 @@ char *s3;
 /*
  * errfl3 - error message in three strings, location given by file and line.
  */
-void errfl3(f, l, s1, s2, s3)
-char *f;
-int l;
-char *s1;
-char *s2;
-char *s3;
+void errfl3(char *f, int l, char *s1, char *s2, char *s3)
    {
    fflush(stdout);
    fprintf(stderr, "%s: File %s; Line %d: %s%s%s\n", progname, f, l,
@@ -130,9 +106,7 @@ char *s3;
  * addrmlst - add a file name to the list of files to be removed if
  *   an error occurs.
  */
-void addrmlst(fname, f)
-char *fname;
-FILE *f;
+void addrmlst(char *fname, FILE *f)
    {
    struct finfo_lst *id;
 
