@@ -213,11 +213,6 @@ function{1} detab(s,i[n])
       if (is_expanded)
          return result;
       else {
-	 long n = DiffPtrs(StrLoc(result),strfree); /* note deallocation */
-	 if (n < 0)
-	    EVVal(-n, E_StrDeAlc);
-	 else
-	    EVVal(n, E_String);
 	 strtotal += DiffPtrs(StrLoc(result),strfree);
          strfree = StrLoc(result);		/* reset the free pointer */
          return s;				/* return original string */
@@ -334,23 +329,12 @@ function{1} entab(s,i[n])
        *  original string (and reset strfree) to conserve memory.
        */
       if (inserted) {
-	 long n;
          StrLen(result) = DiffPtrs(out,StrLoc(result));
-	 n = DiffPtrs(out,strfree);		/* note the deallocation */
-	 if (n < 0)
-	    EVVal(-n, E_StrDeAlc);
-	 else
-	    EVVal(n, E_String);
 	 strtotal += DiffPtrs(out,strfree);
          strfree = out;				/* give back unused space */
          return result;				/* return new string */
          }
       else {
-	 long n = DiffPtrs(StrLoc(result),strfree); /* note the deallocation */
-	 if (n < 0)
-	    EVVal(-n, E_StrDeAlc);
-	 else
-	    EVVal(n, E_String);
 	 strtotal += DiffPtrs(StrLoc(result),strfree);
          strfree = StrLoc(result);		/* reset free pointer */
          return s;				/* return original string */
@@ -363,12 +347,8 @@ end
  *   beyond col
  */
 
-void nxttab(col, tablst, endlst, last, interval)
-C_integer *col;
-dptr *tablst;
-dptr endlst;
-C_integer *last;
-C_integer *interval;
+void nxttab(C_integer *col, dptr *tablst, dptr endlst,
+   C_integer *last, C_integer *interval)
    {
    /*
     * Look for the right tab stop.
@@ -445,12 +425,6 @@ function{1} map(s1,s2,s3)
     */
    if !cnv:string(s1) then
       runerr(103,s1)
-#if COMPILER
-   if !def:string(s2, ucase) then
-      runerr(103,s2)
-   if !def:string(s3, lcase) then
-      runerr(103,s3)
-#endif					/* COMPILER */
 
    abstract {
       return string
@@ -461,12 +435,11 @@ function{1} map(s1,s2,s3)
       register char *str1, *str2, *str3;
       static char maptab[256];
 
-#if !COMPILER
       if (is:null(s2))
          s2 = ucase;
       if (is:null(s3))
          s3 = lcase;
-#endif					/* !COMPILER */
+
       /*
        * If s2 and s3 are the same as for the last call of map,
        *  the current values in maptab can be used. Otherwise, the
@@ -475,13 +448,11 @@ function{1} map(s1,s2,s3)
       if (!EqlDesc(maps2,s2) || !EqlDesc(maps3,s3)) {
          maps2 = s2;
          maps3 = s3;
-
-#if !COMPILER
          if (!cnv:string(s2,s2))
             runerr(103,s2);
          if (!cnv:string(s3,s3))
             runerr(103,s3);
-#endif					/* !COMPILER */
+
          /*
           * s2 and s3 must be of the same length
           */
@@ -565,7 +536,7 @@ function{1} repl(s,n)
        * Make sure the resulting string will not be too long.
        */
       size = n * slen;
-      if (size > MaxStrLen) {
+      if (size > MaxRepl) {
          irunerr(205,n);
          errorfail;
          }
