@@ -78,6 +78,8 @@ function{} exit(status)
       runerr(101, status)
    inline {
       c_exit((int)status);
+      /*NOTREACHED*/
+      return nulldesc;  /* avoid warning */
       }
 end
 
@@ -148,7 +150,6 @@ function{0,1} open(fname, spec)
       register char *s;
       int status;
       char mode[4];
-      extern FILE *fopen();
       FILE *f;
       struct b_file *fl;
 
@@ -247,8 +248,8 @@ function{0,1} open(fname, spec)
 
       if ((status & (Fs_Read|Fs_Write)) == (Fs_Read|Fs_Write))
 	 mode[1] = '+';
-      if ((status & Fs_Untrans) != 0)
-         strcat(mode, "b");
+      if ((status & Fs_Untrans) && ! (status & Fs_Pipe))
+         strcat(mode, "b");		/* not required or allowed by popen() */
 
       /*
        * Open the file with fopen or popen.
@@ -262,9 +263,6 @@ function{0,1} open(fname, spec)
 	 Protect(hp = alclist(0), runerr(0));
 	 Protect(bp = alclstb(MinListSlots, (word)0, 0), runerr(0));
 	 hp->listhead = hp->listtail = (union block *) bp;
-#ifdef ListFix
-	 bp->listprev = bp->listnext = (union block *) hp;
-#endif					/* ListFix */
 
 	 /*
 	  * loop through attributes, checking validity
@@ -287,7 +285,8 @@ function{0,1} open(fname, spec)
 
 #ifdef Pipes
       if (status & Fs_Pipe) {
-	 if (status != (Fs_Read|Fs_Pipe) && status != (Fs_Write|Fs_Pipe))
+	 int m = status & ~(Fs_Pipe | Fs_Untrans);
+	 if (m != Fs_Read && m != Fs_Write)	/* not both, no other flags */
 	    runerr(209, spec);
 	 f = popen(fnamestr, mode);
 	 }
@@ -537,10 +536,6 @@ function{0,1} reads(f,i)
        * We may not have used the entire amount of storage we reserved.
        */
       nbytes = DiffPtrs(StrLoc(s) + tally, strfree);
-      if (nbytes < 0)
-         EVVal(-nbytes, E_StrDeAlc);
-      else
-         EVVal(nbytes, E_String);
       strtotal += nbytes;
       strfree = StrLoc(s) + tally;
       return s;
@@ -693,7 +688,7 @@ function{0,1} where(f)
 
    body {
       FILE *fd;
-      long ftell();
+      long ftell(FILE*);
       long pos;
 
       fd = BlkLoc(f)->file.fd;
@@ -778,6 +773,8 @@ end
 
 #if terminate
 	    c_exit(EXIT_FAILURE);
+	    /*NOTREACHED*/
+	    return nulldesc;  /* avoid warning */
 #else					/* terminate */
 	    return retvalue;
 #endif					/* terminate */
