@@ -55,25 +55,15 @@ keyword{4} collections
       }
 end
 
-#if !COMPILER
 "&column - source column number of current execution point"
 keyword{1} column
    abstract {
       return integer;
       }
    inline {
-#ifdef MultiThread
-#ifdef EventMon
-      return C_integer findcol(ipc.opnd);
-#else					/* EventMon */
       fail;
-#endif					/* EventMon */
-#else
-      fail;
-#endif					/* MultiThread */
       }
 end
-#endif					/* !COMPILER */
 
 "&current - the currently active co-expression"
 keyword{1} current
@@ -93,7 +83,7 @@ keyword{1} date
    inline {
       time_t t;
       struct tm *ct;
-      char sbuf[11], *tmp;
+      char sbuf[32], *tmp;
 
       time(&t);
       ct = localtime(&t);
@@ -259,11 +249,7 @@ keyword{1,*} features
       return string
       }
    body {
-#if COMPILER
-#define Feature(guard,sym,kwval) if ((guard) && (kwval)) suspend C_string kwval;
-#else					/* COMPILER */
 #define Feature(guard,sym,kwval) if (kwval) suspend C_string kwval;
-#endif					/* COMPILER */
 #include "../h/features.h"
       fail;
       }
@@ -275,17 +261,10 @@ keyword{1} file
       return string
       }
    inline {
-#if COMPILER
-      if (line_info)
-         return C_string file_name;
-      else
-         runerr(402);
-#else					/* COMPILER */
       char *s;
       s = findfile(ipc.opnd);
       if (!strcmp(s,"?")) fail;
       return C_string s;
-#endif					/* COMPILER */
       }
 end
 
@@ -332,10 +311,6 @@ keyword{1} level
       }
 
    inline {
-#if COMPILER
-      if (!debug_info)
-         runerr(402);
-#endif					/* COMPILER */
       return C_integer k_level;
       }
 end
@@ -346,14 +321,7 @@ keyword{1} line
       return integer;
       }
    inline {
-#if COMPILER
-      if (line_info)
-         return C_integer line_num;
-      else
-         runerr(402);
-#else					/* COMPILER */
       return C_integer findline(ipc.opnd);
-#endif					/* COMPILER */
       }
 end
 
@@ -460,11 +428,7 @@ keyword{1} source
        return coexpr
        }
    inline {
-#ifndef Coexpr
-         return k_main;
-#else					/* Coexpr */
          return coexpr(topact((struct b_coexpr *)BlkLoc(k_current)));
-#endif					/* Coexpr */
          }
 end
 
@@ -545,9 +509,7 @@ keyword{1} version
    constant Version
 end
 
-#ifndef MultiThread
 struct descrip kywd_xwin[2] = {{D_Null}};
-#endif					/* MultiThread */
 
 "&window - variable containing the current graphics rendering context."
 #ifdef Graphics
