@@ -14,15 +14,6 @@
  */
 #begdef GeneralAsgn(x, y)
 
-#ifdef EventMon
-   body {
-      if (!is:null(curpstate->eventmask) &&
-         Testb((word)E_Assign, curpstate->eventmask)) {
-            EVAsgn(&x);
-	    }
-      }
-#endif					/* EventMon */
-
    type_case x of {
       tvsubs: {
         abstract {
@@ -85,18 +76,10 @@
 
             if (!cnv:C_integer(y, i))
                runerr(101, y);
-
-#ifdef MultiThread
-	    i = cvpos((long)i, StrLen(*(VarLoc(x)+1)));
-#else					/* MultiThread */
             i = cvpos((long)i, StrLen(k_subject));
-#endif					/* MultiThread */
-
             if (i == CvtFail)
                fail;
 	    IntVal(*VarLoc(x)) = i;
-
-            EVVal(k_pos, E_Spos);
             }
          }
       kywdsubj: {
@@ -107,12 +90,7 @@
          if !cnv:string(y, *VarLoc(x)) then
             runerr(103, y);
          inline {
-#ifdef MultiThread
-	    IntVal(*(VarLoc(x)-1)) = 1;
-#else					/* MultiThread */
             k_pos = 1;
-#endif					/* MultiThread */
-            EVVal(k_pos, E_Spos);
             }
          }
       kywdstr: {
@@ -132,12 +110,6 @@
          }
       }
 
-#ifdef EventMon
-   body {
-      EVValD(&y, E_Value);
-      }
-#endif					/* EventMon */
-
 #enddef
 
 
@@ -373,9 +345,7 @@ end
  * subs_asgn - perform assignment to a substring. Leave the updated substring
  *  in dest in case it is needed as the result of the assignment.
  */
-int subs_asgn(dest, src)
-dptr dest;
-const dptr src;
+int subs_asgn(dptr dest, const dptr src)
    {
    tended struct descrip deststr;
    tended struct descrip srcstr;
@@ -460,8 +430,6 @@ const dptr src;
          }
       }
    tvsub->sslen = StrLen(srcstr);
-
-   EVVal(tvsub->sslen, E_Ssasgn);
    return Succeeded;
    }
 
@@ -469,9 +437,7 @@ const dptr src;
  * tvtbl_asgn - perform an assignment to a table element trapped variable,
  *  inserting the element in the table if needed.
  */
-int tvtbl_asgn(dest, src)
-dptr dest;
-const dptr src;
+int tvtbl_asgn(dptr dest, const dptr src)
    {
    tended struct b_tvtbl *bp;
    tended struct descrip tval;
