@@ -11,12 +11,11 @@ static struct region *newregion	(word nbytes, word stdsize);
 
 extern word alcnum;
 
-#ifndef MultiThread
 word coexp_ser = 2;	/* serial numbers for co-expressions; &main is 1 */
+word extl_ser = 1;	/* serial numbers for externals */
 word list_ser = 1;	/* serial numbers for lists */
 word set_ser = 1;	/* serial numbers for sets */
 word table_ser = 1;	/* serial numbers for tables */
-#endif					/* MultiThread */
 
 
 /*
@@ -24,23 +23,12 @@ word table_ser = 1;	/* serial numbers for tables */
  */
 #begdef AlcBlk(var, struct_nm, t_code, nbytes)
 {
-#ifdef MultiThread
-   EVVal((word)nbytes, typech[t_code]);
-#endif					/* MultiThread */
-
    /*
     * Ensure that there is enough room in the block region.
     */
    if (DiffPtrs(blkend,blkfree) < nbytes && !reserve(Blocks, nbytes))
       return NULL;
 
-   /*
-    * If monitoring, show the allocation.
-    */
-#ifndef MultiThread
-   EVVal((word)nbytes, typech[t_code]);
-#endif
-
    /*
     * Decrement the free space in the block region by the number of bytes
     *  allocated and return the address of the first byte of the allocated
@@ -64,11 +52,7 @@ word table_ser = 1;	/* serial numbers for tables */
  */
 #begdef AlcVarBlk(var, struct_nm, t_code, n_desc)
    {
-#ifdef EventMon
-   uword size;
-#else					/* EventMon */
    register uword size;
-#endif					/* EventMon */
 
    /*
     * Variable size blocks are declared with one descriptor, thus
@@ -105,13 +89,11 @@ struct astkblk *alcactiv()
    return abp;
    }
 
-#ifdef LargeInts
 /*
  * alcbignum - allocate an n-digit bignum in the block region
  */
 
-struct b_bignum *alcbignum(n)
-word n;
+struct b_bignum *alcbignum(word n)
    {
    register struct b_bignum *blk;
    register uword size;
@@ -125,133 +107,42 @@ word n;
    blk->lsd = n - 1;
    return blk;
    }
-#endif					/* LargeInts */
 
 /*
  * alccoexp - allocate a co-expression stack block.
+ *
+ * Although pthreads allocates a C stack, we still need this an
+ * interpreter stack beyond the end of the coexpr block.
  */
 
-#if COMPILER
 struct b_coexpr *alccoexp()
    {
    struct b_coexpr *ep;
-   static int serial = 2; /* main co-expression is allocated elsewhere */
+
+   alcnum++;			/* increment allocation count since last g.c. */
+   if (alcnum >= AlcMax)	/* collect garbage every AlcMax coexprs */
+      collect(Static);
+
    ep = (struct b_coexpr *)malloc(stksize);
-
-   /*
-    * If malloc failed or if there have been too many co-expression allocations
-    * since a collection, attempt to free some co-expression blocks and retry.
-    */
-
-   if (ep == NULL || alcnum > AlcMax) {
+   if (ep == NULL) {		/* if can't get space, collect and retry */
       collect(Static);
       ep = (struct b_coexpr *)malloc(stksize);
-      }
-
-   if (ep == NULL)
+   }
+   if (ep == NULL)		/* if still can't get space */
       ReturnErrNum(305, NULL);
 
-   alcnum++;                    /* increment allocation count since last g.c. */
-
-   ep->title = T_Coexpr;
-   ep->size = 0;
-   ep->id = serial++;
-   ep->nextstk = stklist;
-   ep->es_tend = NULL;
-   ep->file_name = "";
-   ep->line_num = 0;
-   ep->freshblk = nulldesc;
-   ep->es_actstk = NULL;
-   ep->cstate[0] = 0;		/* zero the first two cstate words as a flag */
-   ep->cstate[1] = 0;
-   stklist = ep;
-   return ep;
-   }
-#else					/* COMPILER */
-#ifdef MultiThread
-/*
- * If this is a new program being loaded, an icodesize>0 gives the
- * hdr.hsize and a stacksize to use; allocate
- * sizeof(progstate) + icodesize + mstksize
- * Otherwise (icodesize==0), allocate a normal stksize...
- */
-struct b_coexpr *alccoexp(icodesize, stacksize)
-long icodesize, stacksize;
-#else					/* MultiThread */
-struct b_coexpr *alccoexp()
-#endif					/* MultiThread */
-
-   {
-   struct b_coexpr *ep;
-
-#ifdef MultiThread
-   if (icodesize > 0) {
-      ep = (struct b_coexpr *)
-	calloc(1, stacksize+
-		       icodesize+
-		       sizeof(struct progstate)+
-		       sizeof(struct b_coexpr));
-      }
-   else
-#endif					/* MultiThread */
-
-   ep = (struct b_coexpr *)malloc(stksize);
-
-   /*
-    * If malloc failed or if there have been too many co-expression allocations
-    * since a collection, attempt to free some co-expression blocks and retry.
-    */
-
-   if (ep == NULL || alcnum > AlcMax) {
-
-      collect(Static);
-
-#ifdef MultiThread
-      if (icodesize>0) {
-         ep = (struct b_coexpr *)
-	    malloc(mstksize+icodesize+sizeof(struct progstate));
-         }
-      else
-#endif					/* MultiThread */
-
-         ep = (struct b_coexpr *)malloc(stksize);
-      }
-      if (ep == NULL)
-         ReturnErrNum(305, NULL);
-
-   alcnum++;		/* increment allocation count since last g.c. */
-
    ep->title = T_Coexpr;
    ep->es_actstk = NULL;
    ep->size = 0;
-#ifdef MultiThread
-   ep->es_pfp = NULL;
-   ep->es_gfp = NULL;
-   ep->es_argp = NULL;
-   ep->tvalloc = NULL;
-
-   if (icodesize > 0)
-      ep->id = 1;
-   else
-#endif					/* MultiThread */
    ep->id = coexp_ser++;
    ep->nextstk = stklist;
    ep->es_tend = NULL;
    ep->cstate[0] = 0;		/* zero the first two cstate words as a flag */
    ep->cstate[1] = 0;
 
-#ifdef MultiThread
-   /*
-    * Initialize program state to self for &main; curpstate for others.
-    */
-   if(icodesize>0) ep->program = (struct progstate *)(ep+1);
-   else ep->program = curpstate;
-#endif					/* MultiThread */
-
    stklist = ep;
    return ep;
    }
-#endif					/* COMPILER */
 
 /*
  * alccset - allocate a cset in the block region.
@@ -273,14 +164,55 @@ struct b_cset *alccset()
    return blk;
    }
 
+/*
+ * alcexternal - allocate an external data block in the block region.
+ *
+ * nbytes is total struct size including header, or zero to use default
+ * f is dispatch table of user C functions; also differentiates external types
+ * data is copied in to initialize the data block.
+ * Any of these can be zero/null for default behavior.
+ *
+ * May cause a garbage collection.  Returns null if still unsuccessful.
+ */
+
+struct b_external *alcexternal(long nbytes, struct b_extlfuns *f, void *data)
+#passthru #ifdef __clang__ /* tests/general/extlvals fails w/o this */
+#passthru    __attribute__ ((optnone))
+#passthru #endif /*clang*/
+   {
+   struct b_external x;			/* only for faking offsetof */
+   register struct b_external *blk = &x;
+   long datasize;
+   static struct b_extlfuns fdefault; 	/* default dispatch table, all empty */
+
+   if (nbytes == 0)
+      nbytes = sizeof(struct b_external);
+
+   /* datasize = nbytes - offsetof(struct b_external, data); */
+   datasize = nbytes - ((char*)blk->data - (char*)blk);
+   if (datasize < 0)
+      syserr("alcexternal: invalid size");
+
+   /* now, after calculating datasize, round up nbytes to a word multiple */
+   nbytes = (nbytes + sizeof(word) - 1) & ~(sizeof(word) - 1);
+
+   if (f == NULL)
+      f = &fdefault;
+
+   AlcBlk(blk, b_external, T_External, nbytes);
+   blk->blksize = nbytes;
+   blk->id = extl_ser++;
+   blk->funcs = f;
+   if (data != NULL)
+      memcpy(blk->data, data, datasize);
+   return blk;
+   }
+
 /*
  * alcfile - allocate a file block in the block region.
  */
 
-struct b_file *alcfile(fd, status, name)
-FILE *fd;
-int status;
-dptr name;
+struct b_file *alcfile(FILE *fd, int status, dptr name)
    {
    tended struct descrip tname = *name;
    register struct b_file *blk;
@@ -296,8 +228,7 @@ dptr name;
  * alchash - allocate a hashed structure (set or table header) in the block
  *  region.
  */
-union block *alchash(tcode)
-int tcode;
+union block *alchash(int tcode)
    {
    register int i;
    register struct b_set *ps;
@@ -323,8 +254,7 @@ int tcode;
  * alcsegment - allocate a slot block in the block region.
  */
 
-struct b_slots *alcsegment(nslots)
-word nslots;
+struct b_slots *alcsegment(word nslots)
    {
    uword size;
    register struct b_slots *blk;
@@ -343,8 +273,7 @@ word nslots;
  *  Forces a g.c. if there's not enough room for the whole list.
  */
 
-struct b_list *alclist(size)
-uword size;
+struct b_list *alclist(uword size)
    {
    register struct b_list *blk;
 
@@ -362,8 +291,7 @@ uword size;
  * alclstb - allocate a list element block in the block region.
  */
 
-struct b_lelem *alclstb(nslots, first, nused)
-uword nslots, first, nused;
+struct b_lelem *alclstb(uword nslots, uword first, uword nused)
    {
    register struct b_lelem *blk;
    register word i;
@@ -386,15 +314,14 @@ uword nslots, first, nused;
  * alcreal - allocate a real value in the block region.
  */
 
-struct b_real *alcreal(val)
-double val;
+struct b_real *alcreal(double val)
    {
    register struct b_real *blk;
 
    AlcFixBlk(blk, b_real, T_Real)
 
 #ifdef Double
-/* access real values one word at a time */
+   /* store real value one word at a time into possibly unaligned slot */
    { int *rp, *rq;
      rp = (int *) &(blk->realval);
      rq = (int *) &val;
@@ -412,9 +339,7 @@ double val;
  * alcrecd - allocate record with nflds fields in the block region.
  */
 
-struct b_record *alcrecd(nflds, recptr)
-int nflds;
-union block *recptr;
+struct b_record *alcrecd(int nflds, union block *recptr)
    {
    tended union block *trecptr = recptr;
    register struct b_record *blk;
@@ -429,26 +354,7 @@ union block *recptr;
  * alcrefresh - allocate a co-expression refresh block.
  */
 
-#if COMPILER
-struct b_refresh *alcrefresh(na, nl, nt, wrk_sz)
-int na;
-int nl;
-int nt;
-int wrk_sz;
-   {
-   struct b_refresh *blk;
-
-   AlcVarBlk(blk, b_refresh, T_Refresh, na + nl)
-   blk->nlocals = nl;
-   blk->nargs = na;
-   blk->ntemps = nt;
-   blk->wrk_size = wrk_sz;
-   return blk;
-   }
-#else					/* COMPILER */
-struct b_refresh *alcrefresh(entryx, na, nl)
-word *entryx;
-int na, nl;
+struct b_refresh *alcrefresh(word *entryx, int na, int nl)
    {
    struct b_refresh *blk;
 
@@ -457,15 +363,12 @@ int na, nl;
    blk->numlocals = nl;
    return blk;
    }
-#endif					/* COMPILER */
 
 /*
  * alcselem - allocate a set element block.
  */
 
-struct b_selem *alcselem(mbr,hn)
-uword hn;
-dptr mbr;
+struct b_selem *alcselem(dptr mbr, uword hn)
 
    {
    tended struct descrip tmbr = *mbr;
@@ -482,24 +385,12 @@ dptr mbr;
  * alcstr - allocate a string in the string space.
  */
 
-char *alcstr(s, slen)
-register char *s;
-register word slen;
+char *alcstr(char *s, word slen)
    {
    tended struct descrip ts;
    register char *d;
    char *ofree;
 
-#ifdef MultiThread
-   StrLen(ts) = slen;
-   StrLoc(ts) = s;
-#ifdef EventMon
-   if (!noMTevents)
-#endif					/* EventMon */
-      EVVal(slen, E_String);
-   s = StrLoc(ts);
-#endif					/* MultiThread */
-
    /*
     * Make sure there is enough room in the string space.
     */
@@ -534,9 +425,7 @@ register word slen;
  * alcsubs - allocate a substring trapped variable in the block region.
  */
 
-struct b_tvsubs *alcsubs(len, pos, var)
-word len, pos;
-dptr var;
+struct b_tvsubs *alcsubs(word len, word pos, dptr var)
    {
    tended struct descrip tvar = *var;
    register struct b_tvsubs *blk;
@@ -568,9 +457,7 @@ struct b_telem *alctelem()
  *  region.
  */
 
-struct b_tvtbl *alctvtbl(tbl, ref, hashnum)
-register dptr tbl, ref;
-uword hashnum;
+struct b_tvtbl *alctvtbl(dptr tbl, dptr ref, uword hashnum)
    {
    tended struct descrip ttbl = *tbl;
    tended struct descrip tref = *ref;
@@ -588,8 +475,7 @@ uword hashnum;
  *
  *  The block must be the one that is at the very end of a block region.
  */
-void deallocate (bp)
-union block *bp;
+void deallocate(union block *bp)
 {
    word nbytes;
    struct region *rp;
@@ -606,7 +492,6 @@ union block *bp;
       syserr ("deallocation botch");
    rp->free = (char *)bp;
    blktotal -= nbytes;
-   EVVal(nbytes, E_BlkDeAlc);
 }
 
 /*
@@ -624,9 +509,7 @@ union block *bp;
  *  10. give up and signal error.
  */
 
-char *reserve(region, nbytes)
-int region;
-word nbytes;
+char *reserve(int region, word nbytes)
 {
    struct region **pcurr, *curr, *rp;
    word want, newsize;
@@ -691,16 +574,6 @@ word nbytes;
       if (curr->Gprev) curr->Gprev->Gnext = rp;
       curr->Gprev = rp;
       *pcurr = rp;
-#ifdef EventMon
-      if (!noMTevents) {
-         if (region == Strings) {
-            EVVal(rp->size, E_TenureString);
-            }
-         else {
-            EVVal(rp->size, E_TenureBlock);
-            }
-         }
-#endif					/* EventMon */
       return rp->free;
       }
 
@@ -735,9 +608,7 @@ word nbytes;
 /*
  * findgap - search region chain for a region having at least nbytes available
  */
-static struct region *findgap(curr, nbytes)
-struct region *curr;
-word nbytes;
+static struct region *findgap(struct region *curr, word nbytes)
    {
    struct region *rp;
 
@@ -754,8 +625,7 @@ word nbytes;
  * newregion - try to malloc a new region and tenure the old one,
  *  backing off if the requested size fails.
  */
-static struct region *newregion(nbytes,stdsize)
-word nbytes,stdsize;
+static struct region *newregion(word nbytes, word stdsize)
 {
    uword minSize = MinAbrSize;
    struct region *rp;
